@@ -1,6 +1,7 @@
 # pylint: disable=E1103
 
 
+from pandas.types.common import is_list_like, is_scalar
 from pandas import Series, DataFrame
 from pandas.core.index import MultiIndex, Index
 from pandas.core.groupby import Grouper
@@ -9,7 +10,6 @@ from pandas.tools.util import cartesian_product
 from pandas.compat import range, lrange, zip
 from pandas import compat
 import pandas.core.common as com
-import pandas.lib as lib
 import numpy as np
 
 
@@ -86,7 +86,7 @@ def pivot_table(data, values=None, index=None, columns=None, aggfunc='mean',
             table = pivot_table(data, values=values, index=index,
                                 columns=columns,
                                 fill_value=fill_value, aggfunc=func,
-                                margins=margins)
+                                margins=margins, margins_name=margins_name)
             pieces.append(table)
             keys.append(func.__name__)
         return concat(pieces, keys=keys, axis=1)
@@ -95,16 +95,13 @@ def pivot_table(data, values=None, index=None, columns=None, aggfunc='mean',
 
     values_passed = values is not None
     if values_passed:
-        if com.is_list_like(values):
+        if is_list_like(values):
             values_multi = True
             values = list(values)
         else:
             values_multi = False
             values = [values]
-    else:
-        values = list(data.columns.drop(keys))
 
-    if values_passed:
         to_filter = []
         for x in keys + values:
             if isinstance(x, Grouper):
@@ -117,6 +114,15 @@ def pivot_table(data, values=None, index=None, columns=None, aggfunc='mean',
         if len(to_filter) < len(data.columns):
             data = data[to_filter]
 
+    else:
+        values = data.columns
+        for key in keys:
+            try:
+                values = values.drop(key)
+            except (TypeError, ValueError):
+                pass
+        values = list(values)
+
     grouped = data.groupby(keys)
     agged = grouped.agg(aggfunc)
 
@@ -361,7 +367,7 @@ def _generate_marginal_results_without_values(
 def _convert_by(by):
     if by is None:
         by = []
-    elif (lib.isscalar(by) or
+    elif (is_scalar(by) or
           isinstance(by, (np.ndarray, Index, Series, Grouper)) or
           hasattr(by, '__call__')):
         by = [by]
@@ -410,7 +416,11 @@ def crosstab(index, columns, values=None, rownames=None, colnames=None,
     Notes
     -----
     Any Series passed will have their name attributes used unless row or column
-    names for the cross-tabulation are specified
+    names for the cross-tabulation are specified.
+
+    Any input passed containing Categorical data will have **all** of its
+    categories included in the cross-tabulation, even if the actual data does
+    not contain any instances of a particular category.
 
     In the event that there aren't overlapping indexes an empty DataFrame will
     be returned.
@@ -434,6 +444,16 @@ def crosstab(index, columns, values=None, rownames=None, colnames=None,
     bar  1     2      1     0
     foo  2     2      1     2
 
+    >>> foo = pd.Categorical(['a', 'b'], categories=['a', 'b', 'c'])
+    >>> bar = pd.Categorical(['d', 'e'], categories=['d', 'e', 'f'])
+    >>> crosstab(foo, bar)  # 'c' and 'f' are not represented in the data,
+                            # but they still will be counted in the output
+    col_0  d  e  f
+    row_0
+    a      1  0  0
+    b      0  1  0
+    c      0  0  0
+
     Returns
     -------
     crosstab : DataFrame
@@ -509,6 +529,9 @@ def _normalize(table, normalize, margins):
         column_margin = table.loc[:, 'All'].drop('All')
         index_margin = table.loc['All', :].drop('All')
         table = table.drop('All', axis=1).drop('All')
+        # to keep index and columns names
+        table_index_names = table.index.names
+        table_columns_names = table.columns.names
 
         # Normalize core
         table = _normalize(table, normalize=normalize, margins=False)
@@ -536,6 +559,9 @@ def _normalize(table, normalize, margins):
         else:
             raise ValueError("Not a valid normalize argument")
 
+        table.index.names = table_index_names
+        table.columns.names = table_columns_names
+
     else:
         raise ValueError("Not a valid margins argument")
 
